@@ -6,6 +6,7 @@ package middleware
 
 import (
 	"context"
+
 	"github.com/aws/aws-sdk-go-v2/aws/middleware/private/metrics"
 	"github.com/aws/aws-sdk-go-v2/internal/sdk"
 	"github.com/aws/smithy-go/middleware"
@@ -21,6 +22,8 @@ func (m *EndpointResolutionEnd) ID() string {
 	return "EndpointResolutionEnd"
 }
 
+// Deprecated: Endpoint resolution now occurs in Finalize. The ResolveEndpoint
+// middleware remains in serialize but is largely a no-op.
 func (m *EndpointResolutionEnd) HandleSerialize(
 	ctx context.Context, in middleware.SerializeInput, next middleware.SerializeHandler,
 ) (
@@ -34,3 +37,13 @@ func (m *EndpointResolutionEnd) HandleSerialize(
 
 	return out, metadata, err
 }
+
+func (m *EndpointResolutionEnd) HandleFinalize(
+	ctx context.Context, in middleware.FinalizeInput, next middleware.FinalizeHandler,
+) (
+	middleware.FinalizeOutput, middleware.Metadata, error,
+) {
+	mctx := metrics.Context(ctx)
+	mctx.Data().ResolveEndpointEndTime = sdk.NowTime()
+	return next.HandleFinalize(ctx, in)
+}
