@@ -38,7 +38,7 @@ import software.amazon.smithy.utils.SetUtils;
 /**
  * Utility methods for generating AWS protocols.
  */
-final class AwsProtocolUtils {
+public final class AwsProtocolUtils {
     private AwsProtocolUtils() {
     }
 
@@ -47,7 +47,7 @@ final class AwsProtocolUtils {
      *
      * @param context The generation context.
      */
-    static void generateHttpProtocolTests(GenerationContext context) {
+    public static void generateHttpProtocolTests(GenerationContext context) {
         Set<HttpProtocolUnitTestGenerator.ConfigValue> configValues = new TreeSet<>(SetUtils.of(
                 HttpProtocolUnitTestGenerator.ConfigValue.builder()
                         .name(AddAwsConfigFields.REGION_CONFIG_NAME)
@@ -107,6 +107,17 @@ final class AwsProtocolUtils {
 
         // skip request compression tests, not yet implemented in the SDK
         Set<HttpProtocolUnitTestGenerator.SkipTest> inputSkipTests = new TreeSet<>(SetUtils.of(
+                // CBOR default value serialization (SHOULD)
+                HttpProtocolUnitTestGenerator.SkipTest.builder()
+                        .service(ShapeId.from("smithy.protocoltests.rpcv2Cbor#RpcV2Protocol"))
+                        .operation(ShapeId.from("smithy.protocoltests.rpcv2Cbor#OperationWithDefaults"))
+                        .addTestName("RpcV2CborClientPopulatesDefaultValuesInInput")
+                        .addTestName("RpcV2CborClientSkipsTopLevelDefaultValuesInInput")
+                        .addTestName("RpcV2CborClientUsesExplicitlyProvidedMemberValuesOverDefaults")
+                        .addTestName("RpcV2CborClientUsesExplicitlyProvidedValuesInTopLevel")
+                        .addTestName("RpcV2CborClientIgnoresNonTopLevelDefaultsOnMembersWithClientOptional")
+                        .build(),
+
                 HttpProtocolUnitTestGenerator.SkipTest.builder()
                         .service(ShapeId.from("aws.protocoltests.restxml#RestXml"))
                         .operation(ShapeId.from("aws.protocoltests.restxml#HttpPayloadWithUnion"))
@@ -114,6 +125,18 @@ final class AwsProtocolUtils {
                         .addTestName("RestXmlHttpPayloadWithUnsetUnion")
                         .build(),
 
+                // REST-JSON default value serialization
+                HttpProtocolUnitTestGenerator.SkipTest.builder()
+                        .service(ShapeId.from("aws.protocoltests.restjson#RestJson"))
+                        .operation(ShapeId.from("aws.protocoltests.restjson#OperationWithDefaults"))
+                        .addTestName("RestJsonClientPopulatesDefaultValuesInInput")
+                        .addTestName("RestJsonClientUsesExplicitlyProvidedValuesInTopLevel")
+                        .build(),
+                HttpProtocolUnitTestGenerator.SkipTest.builder()
+                        .service(ShapeId.from("aws.protocoltests.restjson#RestJson"))
+                        .operation(ShapeId.from("aws.protocoltests.restjson#OperationWithNestedStructure"))
+                        .addTestName("RestJsonClientPopulatesNestedDefaultValuesWhenMissing")
+                        .build(),
 
                 HttpProtocolUnitTestGenerator.SkipTest.builder()
                         .service(ShapeId.from("aws.protocoltests.json10#JsonRpc10"))
@@ -131,6 +154,19 @@ final class AwsProtocolUtils {
                 ));
 
         Set<HttpProtocolUnitTestGenerator.SkipTest> outputSkipTests = new TreeSet<>(SetUtils.of(
+                // CBOR default value deserialization (SHOULD)
+                HttpProtocolUnitTestGenerator.SkipTest.builder()
+                        .service(ShapeId.from("smithy.protocoltests.rpcv2Cbor#RpcV2Protocol"))
+                        .operation(ShapeId.from("smithy.protocoltests.rpcv2Cbor#OperationWithDefaults"))
+                        .addTestName("RpcV2CborClientPopulatesDefaultsValuesWhenMissingInResponse")
+                        .addTestName("RpcV2CborClientIgnoresDefaultValuesIfMemberValuesArePresentInResponse")
+                        .build(),
+                HttpProtocolUnitTestGenerator.SkipTest.builder()
+                        .service(ShapeId.from("smithy.protocoltests.rpcv2Cbor#RpcV2Protocol"))
+                        .operation(ShapeId.from("smithy.protocoltests.rpcv2Cbor#RpcV2CborDenseMaps"))
+                        .addTestName("RpcV2CborDeserializesDenseSetMapAndSkipsNull")
+                        .build(),
+
                 // REST-JSON optional (SHOULD) test cases
                 HttpProtocolUnitTestGenerator.SkipTest.builder()
                         .service(ShapeId.from("aws.protocoltests.restjson#RestJson"))
@@ -138,6 +174,18 @@ final class AwsProtocolUtils {
                         .addTestName("RestJsonDeserializesDenseSetMapAndSkipsNull")
                         .build(),
 
+                // REST-JSON default value deserialization
+                HttpProtocolUnitTestGenerator.SkipTest.builder()
+                        .service(ShapeId.from("aws.protocoltests.restjson#RestJson"))
+                        .operation(ShapeId.from("aws.protocoltests.restjson#OperationWithDefaults"))
+                        .addTestName("RestJsonClientPopulatesDefaultsValuesWhenMissingInResponse")
+                        .build(),
+                HttpProtocolUnitTestGenerator.SkipTest.builder()
+                        .service(ShapeId.from("aws.protocoltests.restjson#RestJson"))
+                        .operation(ShapeId.from("aws.protocoltests.restjson#OperationWithNestedStructure"))
+                        .addTestName("RestJsonClientPopulatesNestedDefaultsWhenMissingInResponseBody")
+                        .build(),
+
                 // REST-XML opinionated test - prefix headers as empty vs nil map
                 HttpProtocolUnitTestGenerator.SkipTest.builder()
                         .service(ShapeId.from("aws.protocoltests.restxml#RestXml"))
