@@ -22,7 +22,6 @@ import java.util.List;
 import java.util.Set;
 import java.util.TreeSet;
 import java.util.stream.Collectors;
-import software.amazon.smithy.aws.go.codegen.AwsSignatureVersion4aUtils;
 import software.amazon.smithy.codegen.core.CodegenException;
 import software.amazon.smithy.codegen.core.Symbol;
 import software.amazon.smithy.codegen.core.SymbolProvider;
@@ -48,8 +47,7 @@ import software.amazon.smithy.utils.SetUtils;
 import static software.amazon.smithy.go.codegen.SymbolUtils.buildPackageSymbol;
 
 /**
- * S3UpdateEndpoint integration serves to apply customizations for S3 service,
- * and modifies the resolved endpoint based on S3 client config or input shape values.
+ * S3UpdateEndpoint integration applies legacy (pre-EndpointResolverV2) endpoint customizations for the S3 service.
  */
 public class S3UpdateEndpoint implements GoIntegration {
     // Middleware name
@@ -259,13 +257,6 @@ public class S3UpdateEndpoint implements GoIntegration {
                                                     .putProperty(SymbolUtils.GO_UNIVERSE_TYPE, true)
                                                     .build())
                                             .documentation("Allows you to disable S3 Multi-Region access points feature.")
-                                            .build(),
-                                    ConfigField.builder()
-                                            .name(AwsSignatureVersion4aUtils.V4A_SIGNER_INTERFACE_NAME)
-                                            .type(SymbolUtils.createValueSymbolBuilder(
-                                                            AwsSignatureVersion4aUtils.V4A_SIGNER_INTERFACE_NAME)
-                                                    .build())
-                                            .documentation("Signature Version 4a (SigV4a) Signer")
                                             .build()
                             ))
                             .build()
