@@ -16,7 +16,6 @@ import (
 	"github.com/aws/aws-sdk-go-v2/internal/ini"
 	"github.com/aws/smithy-go/logging"
 	"github.com/aws/smithy-go/ptr"
-	"github.com/google/go-cmp/cmp"
 )
 
 var _ regionProvider = (*SharedConfig)(nil)
@@ -730,6 +729,35 @@ func TestNewSharedConfig(t *testing.T) {
 				},
 			},
 		},
+		"profile with aws account ID": {
+			ConfigFilenames: []string{testConfigFilename},
+			Profile:         "account_id",
+			Expected: SharedConfig{
+				Profile: "account_id",
+				Credentials: aws.Credentials{
+					AccessKeyID:     "account_id_akid",
+					SecretAccessKey: "account_id_secret",
+					Source:          fmt.Sprintf("SharedConfigCredentials: %s", testConfigFilename),
+					AccountID:       "012345678901",
+				},
+			},
+		},
+		"profile with account ID endpoint mode": {
+			ConfigFilenames: []string{testConfigFilename},
+			Profile:         "account_id_endpoint_mode",
+			Expected: SharedConfig{
+				Profile:               "account_id_endpoint_mode",
+				AccountIDEndpointMode: aws.AccountIDEndpointModeDisabled,
+			},
+		},
+		"profile with invalid account ID endpoint mode": {
+			ConfigFilenames: []string{testConfigFilename},
+			Profile:         "account_id_endpoint_mode_error",
+			Expected: SharedConfig{
+				Profile: "account_id_endpoint_mode_error",
+			},
+			Err: fmt.Errorf("invalid value for shared config profile field, account_id_endpoint_mode=blabla, must be preferred/required/disabled"),
+		},
 	}
 
 	for name, c := range cases {
@@ -754,7 +782,7 @@ func TestNewSharedConfig(t *testing.T) {
 			if c.Err != nil {
 				t.Errorf("expect error: %v, got none", c.Err)
 			}
-			if diff := cmp.Diff(c.Expected, cfg); len(diff) > 0 {
+			if diff := cmpDiff(c.Expected, cfg); len(diff) > 0 {
 				t.Error(diff)
 			}
 		})
@@ -895,7 +923,7 @@ func TestLoadSharedConfigFromSection(t *testing.T) {
 				t.Fatalf("expect no error, got %v", err)
 			}
 
-			if diff := cmp.Diff(c.Expected, cfg); diff != "" {
+			if diff := cmpDiff(c.Expected, cfg); diff != "" {
 				t.Errorf("expect shared config match\n%s", diff)
 			}
 		})
@@ -1499,7 +1527,7 @@ func TestSharedConfigLoading(t *testing.T) {
 				t.Fatalf("expect no error, got %v", err)
 			}
 
-			if diff := cmp.Diff(c.Expect, cfg); diff != "" {
+			if diff := cmpDiff(c.Expect, cfg); diff != "" {
 				t.Errorf("expect shared config match\n%s", diff)
 			}
 		})
