@@ -354,8 +354,7 @@ func MarshalListWithOptions(in interface{}, optFns ...func(*EncoderOptions)) ([]
 	return asList.Value, nil
 }
 
-// EncoderOptions is a collection of options shared between marshaling
-// and unmarshaling
+// EncoderOptions is a collection of options used by the marshaler.
 type EncoderOptions struct {
 	// Support other custom struct tag keys, such as `yaml`, `json`, or `toml`.
 	// Note that values provided with a custom TagKey must also be supported
@@ -380,6 +379,19 @@ type EncoderOptions struct {
 	//
 	// Default encoding is time.RFC3339Nano in a DynamoDBStreams String (S) data type.
 	EncodeTime func(time.Time) (types.AttributeValue, error)
+
+	// When enabled, the encoder will use implementations of
+	// encoding.TextMarshaler and encoding.BinaryMarshaler when present on
+	// marshaled values.
+	//
+	// Implementations are checked in the following order:
+	//   - [Marshaler]
+	//   - encoding.TextMarshaler
+	//   - encoding.BinaryMarshaler
+	//
+	// The results of a MarshalText call will convert to string (S), results
+	// from a MarshalBinary call will convert to binary (B).
+	UseEncodingMarshalers bool
 }
 
 // An Encoder provides marshaling Go value types to AttributeValues.
@@ -438,7 +450,7 @@ func (e *Encoder) encode(v reflect.Value, fieldTag tag) (types.AttributeValue, e
 	v = valueElem(v)
 
 	if v.Kind() != reflect.Invalid {
-		if av, err := tryMarshaler(v); err != nil {
+		if av, err := e.tryMarshaler(v); err != nil {
 			return nil, err
 		} else if av != nil {
 			return av, nil
@@ -714,11 +726,6 @@ func (e *Encoder) encodeScalar(v reflect.Value, fieldTag tag) (types.AttributeVa
 }
 
 func (e *Encoder) encodeNumber(v reflect.Value) (types.AttributeValue, error) {
-	if av, err := tryMarshaler(v); err != nil {
-		return nil, err
-	} else if av != nil {
-		return av, nil
-	}
 
 	var out string
 	switch v.Kind() {
@@ -742,11 +749,6 @@ func (e *Encoder) encodeNumber(v reflect.Value) (types.AttributeValue, error) {
 }
 
 func (e *Encoder) encodeString(v reflect.Value) (types.AttributeValue, error) {
-	if av, err := tryMarshaler(v); err != nil {
-		return nil, err
-	} else if av != nil {
-		return av, nil
-	}
 
 	switch v.Kind() {
 	case reflect.String:
@@ -832,7 +834,7 @@ func isNullableZeroValue(v reflect.Value) bool {
 	return false
 }
 
-func tryMarshaler(v reflect.Value) (types.AttributeValue, error) {
+func (e *Encoder) tryMarshaler(v reflect.Value) (types.AttributeValue, error) {
 	if v.Kind() != reflect.Ptr && v.Type().Name() != "" && v.CanAddr() {
 		v = v.Addr()
 	}
@@ -841,9 +843,35 @@ func tryMarshaler(v reflect.Value) (types.AttributeValue, error) {
 		return nil, nil
 	}
 
-	if m, ok := v.Interface().(Marshaler); ok {
+	i := v.Interface()
+	if m, ok := i.(Marshaler); ok {
 		return m.MarshalDynamoDBStreamsAttributeValue()
 	}
+	if e.options.UseEncodingMarshalers {
+		return e.tryEncodingMarshaler(i)
+	}
+
+	return nil, nil
+}
+
+func (e *Encoder) tryEncodingMarshaler(v any) (types.AttributeValue, error) {
+	if m, ok := v.(encoding.TextMarshaler); ok {
+		s, err := m.MarshalText()
+		if err != nil {
+			return nil, err
+		}
+
+		return &types.AttributeValueMemberS{Value: string(s)}, nil
+	}
+
+	if m, ok := v.(encoding.BinaryMarshaler); ok {
+		b, err := m.MarshalBinary()
+		if err != nil {
+			return nil, err
+		}
+
+		return &types.AttributeValueMemberB{Value: b}, nil
+	}
 
 	return nil, nil
 }
